==> flspp_modified-1.2.tar.gz: flspp_modified-1.2/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

from setuptools import Extension
from setuptools.command.build_ext import build_ext

extension = Extension(
    name="flspp._core",
    sources=[
        "flspp/_core.cpp",
        "flspp/cpp/clustering_algorithm.cpp",
        "flspp/cpp/clustering.cpp",
        "flspp/cpp/makros.cpp",
        "flspp/cpp/random_generator.cpp",
    ],
    include_dirs=["flspp"],
)

# Thank you https://github.com/dstein64/kmeans1d!


class BuildExt(build_ext):
    """A custom build extension for adding -stdlib arguments for clang++."""

    def build_extensions(self) -> None:
        # '-std=c++11' is added to `extra_compile_args` so the code can compile
        # with clang++. This works across compilers (ignored by MSVC).
        for extension in self.extensions:
            extension.extra_compile_args.append("-std=c++11")

        try:
            build_ext.build_extensions(self)
        except:
            # Workaround Issue #2.
            # '-stdlib=libc++' is added to `extra_compile_args` and `extra_link_args`
            # so the code can compile on macOS with Anaconda.
            for extension in self.extensions:
                extension.extra_compile_args.append("-stdlib=libc++")
                extension.extra_link_args.append("-stdlib=libc++")
            build_ext.build_extensions(self)


def build(setup_kwargs) -> None:
    setup_kwargs.update(
        {"ext_modules": [extension], "cmdclass": {"build_ext": BuildExt}}
    )


packages = \
['flspp']

package_data = \
{'': ['*'], 'flspp': ['cpp/*']}

requires_list = open('./requirements.txt', 'r', encoding='utf8').readlines()
requires_list = [i.strip() for i in requires_list]

setup_kwargs = {
    'name': 'flspp_modified',
    'version': '1.2',
    'description': 'Implementation of the FLS++ algorithm for K-Means clustering.',
    'packages': packages,
    'package_data': package_data,
    'install_requires': requires_list,
    'python_requires': '>=3.9,<4.0',
}


build(setup_kwargs)

setup(**setup_kwargs)

==> flspp_modified-1.3.tar.gz: flspp_modified-1.3/setup.py <==
# -*- coding: utf-8 -*-
from setuptools import setup

from setuptools import Extension
from setuptools.command.build_ext import build_ext

extension = Extension(
    name="flspp._core",
    sources=[
        "flspp/_core.cpp",
        "flspp/cpp/clustering_algorithm.cpp",
        "flspp/cpp/clustering.cpp",
        "flspp/cpp/makros.cpp",
        "flspp/cpp/random_generator.cpp",
    ],
    include_dirs=["flspp"],
)

# Thank you https://github.com/dstein64/kmeans1d!


class BuildExt(build_ext):
    """A custom build extension for adding -stdlib arguments for clang++."""

    def build_extensions(self) -> None:
        # '-std=c++11' is added to `extra_compile_args` so the code can compile
        # with clang++. This works across compilers (ignored by MSVC).
        for extension in self.extensions:
            extension.extra_compile_args.append("-std=c++11")

        try:
            build_ext.build_extensions(self)
        except:
            # Workaround Issue #2.
            # '-stdlib=libc++' is added to `extra_compile_args` and `extra_link_args`
            # so the code can compile on macOS with Anaconda.
            for extension in self.extensions:
                extension.extra_compile_args.append("-stdlib=libc++")
                extension.extra_link_args.append("-stdlib=libc++")
            build_ext.build_extensions(self)


def build(setup_kwargs) -> None:
    setup_kwargs.update(
        {"ext_modules": [extension], "cmdclass": {"build_ext": BuildExt}}
    )


packages = \
['flspp']

package_data = \
{'': ['*'], 'flspp': ['cpp/*']}

requires_list = ['numpy==1.23.5', 'scikit-learn==0.23.2']
setup_kwargs = {
    'name': 'flspp_modified',
    'version': '1.3',
    'description': 'Implementation of the FLS++ algorithm for K-Means clustering.',
    'packages': packages,
    'package_data': package_data,
    'install_requires': requires_list,
    'python_requires': '>=3.9,<4.0',
}


build(setup_kwargs)

setup(**setup_kwargs)
